@@ -6,15 +6,21 @@ from importlib import import_module
 
 from .shtab import complete
 
-logger = logging.getLogger(__name__)
+log = logging.getLogger(__name__)
 
 
 def get_main_parser():
     parser = argparse.ArgumentParser(prog="shtab")
-    parser.add_argument("parser")
+    parser.add_argument(
+        "parser", help="importable parser (or fuction returning parser)"
+    )
     parser.add_argument(
         "-s", "--shell", default="bash", choices=["bash", "zsh"]
     )
+    parser.add_argument(
+        "--prefix", help="prepended to generated functions to avoid clashes"
+    )
+    parser.add_argument("--preamble", help="prepended to generated script")
     parser.add_argument(
         "-u",
         "--error-unimportable",
@@ -28,6 +34,7 @@ def get_main_parser():
 def main(argv=None):
     parser = get_main_parser()
     args = parser.parse_args(argv)
+    log.debug(args)
 
     module, other_parser = args.parser.rsplit(".", 1)
     try:
@@ -35,7 +42,7 @@ def main(argv=None):
     except ImportError as err:
         if args.error_unimportable:
             raise
-        logger.debug(str(err))
+        log.debug(str(err))
         return
     other_parser = getattr(module, other_parser)
     if callable(other_parser):
@@ -44,10 +51,12 @@ def main(argv=None):
         complete(
             other_parser,
             shell=args.shell,
-            root_prefix=args.parser.split(".", 1)[0],
+            root_prefix=args.prefix or args.parser.split(".", 1)[0],
+            preamble=args.preamble,
         )
     )
 
 
 if __name__ == "__main__":
+    logging.basicConfig(level=logging.INFO)
     main()
